Struct DatabaseTransaction
pub struct DatabaseTransaction { /* private fields */ }Expand description
Defines a database transaction, whether it is an open transaction and the type of backend to use. Under the hood, a Transaction is just a wrapper for a connection where START TRANSACTION has been executed.
Implementations