Struct Deleter
pub struct Deleter { /* private fields */ }Expand description
Handles DELETE operations in a ActiveModel using DeleteStatement
Implementations
impl Deleter
impl Deleter
pub fn new(query: DeleteStatement) -> Self
pub fn new(query: DeleteStatement) -> Self
Instantiate a new Deleter by passing it a DeleteStatement
pub async fn exec<C>(self, db: &C) -> Result<DeleteResult, DbErr>where
C: ConnectionTrait,
pub async fn exec<C>(self, db: &C) -> Result<DeleteResult, DbErr>where
C: ConnectionTrait,
Execute a DELETE operation
pub async fn exec_with_returning<E, C>(
self,
db: &C,
) -> Result<Vec<E::Model>, DbErr>where
E: EntityTrait,
C: ConnectionTrait,
pub async fn exec_with_returning<E, C>(
self,
db: &C,
) -> Result<Vec<E::Model>, DbErr>where
E: EntityTrait,
C: ConnectionTrait,
Execute an delete operation and return the deleted model