Struct ProxyExecResult
pub struct ProxyExecResult {
pub last_insert_id: u64,
pub rows_affected: u64,
}Expand description
Defines the results obtained from a [ProxyDatabase]
Fields
last_insert_id: u64The last inserted id on auto-increment
rows_affected: u64The number of rows affected by the database operation
Implementations
impl ProxyExecResult
impl ProxyExecResult
pub fn new(last_insert_id: u64, rows_affected: u64) -> Self
pub fn new(last_insert_id: u64, rows_affected: u64) -> Self
Create a new ProxyExecResult from the last inserted id and the number of rows affected