Struct SqlzMsSqlPoolConnection
pub struct SqlzMsSqlPoolConnection { /* private fields */ }Expand description
Defines a sqlz MSSQL pool
Implementations
impl SqlzMsSqlPoolConnection
impl SqlzMsSqlPoolConnection
pub async fn execute(&self, stmt: Statement) -> Result<ExecResult, DbErr>
pub async fn execute(&self, stmt: Statement) -> Result<ExecResult, DbErr>
Execute a Statement on a MSSQL backend
pub async fn execute_unprepared(&self, sql: &str) -> Result<ExecResult, DbErr>
pub async fn execute_unprepared(&self, sql: &str) -> Result<ExecResult, DbErr>
Execute an unprepared SQL statement on a MSSQL backend
Uses the raw SQLBatch TDS path (not sp_executesql) so that temp tables created here are visible to subsequent queries on the same connection.
pub async fn query_one(
&self,
stmt: Statement,
) -> Result<Option<QueryResult>, DbErr>
pub async fn query_one( &self, stmt: Statement, ) -> Result<Option<QueryResult>, DbErr>
Get one result from a SQL query. Returns Option::None if no match was found
pub async fn query_all(
&self,
stmt: Statement,
) -> Result<Vec<QueryResult>, DbErr>
pub async fn query_all( &self, stmt: Statement, ) -> Result<Vec<QueryResult>, DbErr>
Get the results of a query returning them as a Vec<QueryResult>
pub async fn stream(&self, stmt: Statement) -> Result<QueryStream, DbErr>
pub async fn stream(&self, stmt: Statement) -> Result<QueryStream, DbErr>
Stream the results of executing a SQL query
pub async fn begin(
&self,
isolation_level: Option<IsolationLevel>,
access_mode: Option<AccessMode>,
) -> Result<DatabaseTransaction, DbErr>
pub async fn begin( &self, isolation_level: Option<IsolationLevel>, access_mode: Option<AccessMode>, ) -> Result<DatabaseTransaction, DbErr>
Bundle a set of SQL statements that execute together.
pub async fn transaction<F, T, E>(
&self,
callback: F,
isolation_level: Option<IsolationLevel>,
access_mode: Option<AccessMode>,
) -> Result<T, TransactionError<E>>
pub async fn transaction<F, T, E>( &self, callback: F, isolation_level: Option<IsolationLevel>, access_mode: Option<AccessMode>, ) -> Result<T, TransactionError<E>>
Create a MySQL transaction
pub async fn close(self) -> Result<(), DbErr>
pub async fn close(self) -> Result<(), DbErr>
Explicitly close the MSSQL connection
See Self::close_by_ref for usage with references.
pub async fn close_by_ref(&self) -> Result<(), DbErr>
pub async fn close_by_ref(&self) -> Result<(), DbErr>
Explicitly close the MSSQL connection
pub fn get_schema(&self) -> Option<&str>
pub fn get_schema(&self) -> Option<&str>
Get database schema that specified in the connection string