Enum TryInsertResult
pub enum TryInsertResult<T> {
Empty,
Conflicted,
Inserted(T),
}Expand description
The result of executing a crate::TryInsert.
This enum represents no‑op inserts (e.g. conflict DO NOTHING) without treating
them as errors.
Variants
Empty
There was nothing to insert, so no SQL was executed.
This typically happens when creating a crate::TryInsert from an empty iterator or None.
Conflicted
The statement was executed, but SeaORM could not get the inserted row / insert id.
This is commonly caused by ON CONFLICT ... DO NOTHING (Postgres / SQLite) or the MySQL
polyfill (ON DUPLICATE KEY UPDATE pk = pk).
Note that this variant maps from DbErr::RecordNotInserted, so it can also represent other
situations where the backend/driver reports no inserted row (e.g. an empty RETURNING
result set or a “no-op” update in MySQL where last_insert_id is reported as 0). In rare
cases, this can be a false negative where a row was inserted but the backend did not report
it.
Inserted(T)
Successfully inserted
Implementations
impl<A> TryInsertResult<InsertResult<A>>where
A: ActiveModelTrait,
impl<A> TryInsertResult<InsertResult<A>>where
A: ActiveModelTrait,
pub fn last_insert_id(
self,
) -> Result<Option<<<<A as ActiveModelTrait>::Entity as EntityTrait>::PrimaryKey as PrimaryKeyTrait>::ValueType>, DbErr>
pub fn last_insert_id( self, ) -> Result<Option<<<<A as ActiveModelTrait>::Entity as EntityTrait>::PrimaryKey as PrimaryKeyTrait>::ValueType>, DbErr>
Extract the last inserted id.
TryInsertResult::Empty=>Ok(None)TryInsertResult::Inserted=>Ok(Some(last_insert_id))TryInsertResult::Conflicted=>Err(DbErr::RecordNotInserted)